@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: project-template
 version: 0.2.0
-id: project-template-0.2.0-cfd687309e52e13b0d0d1443c21dd612
-key: proje_B1Jn23tOB3LCKEpGEzrZvK
+id: project-template-0.2.0-044046e2229f6d1c68566afe3ade513d
+key: proje_1k7jOIGP9yYBSL6tOfqJHZ
 license: BSD3
 maintainer: michael@fpcomplete.com
 homepage: https://github.com/fpco/haskell-ide
@@ -19,18 +19,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/project-template-0.2.0
-hs-libraries: HSproject-template-0.2.0-B1Jn23tOB3LCKEpGEzrZvK
+hs-libraries: HSproject-template-0.2.0-1k7jOIGP9yYBSL6tOfqJHZ
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
-    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
